DoublyLinkedList

Struct DoublyLinkedList 

pub struct DoublyLinkedList<T> {
    pub head: Option<Box<ListNode<T>>>,
    pub length: usize,
}

Fields

head: Option<Box<ListNode<T>>>length: usize

Implementations

Source

impl<T> DoublyLinkedList<T>

pub fn new() -> DoublyLinkedList<T>

Creates a new empty DoublyLinkedList.

Examples
use data_structures::doubly_linked_list::DoublyLinkedList;
struct T;
let list:DoublyLinkedList<T> = DoublyLinkedList::new();
assert!(list.is_empty());
pub fn with_value(data: T) -> DoublyLinkedList<T>

Creates a new DoublyLinkedList initialized with a single element.

Parameters
  • data: The initial value for the first node in the list.
Examples
use data_structures::doubly_linked_list::DoublyLinkedList;
let list = DoublyLinkedList::with_value(42);
assert_eq!(list.length, 1);
pub fn is_empty(&self) -> bool

Checks if the DoublyLinkedList is empty.

Returns

true if the list has no elements, and false otherwise

Examples
use data_structures::doubly_linked_list::DoublyLinkedList;

let empty_list: DoublyLinkedList<i32> = DoublyLinkedList::new();
assert!(empty_list.is_empty());

let list: DoublyLinkedList<i32> = DoublyLinkedList::with_value(30);
assert!(!list.is_empty());